@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Base;
 
-our $DATE = '2016-02-26'; # DATE
-our $VERSION = '1.51'; # VERSION
+our $DATE = '2016-03-16'; # DATE
+our $VERSION = '1.52'; # VERSION
 
 use 5.010001;
 use strict;
@@ -1005,8 +1005,8 @@ sub __gen_iter {
         };
     } else {
         # expect JSON stream for non-simple types
-        require JSON;
-        state $json = JSON->new->allow_nonref;
+        require JSON::MaybeXS;
+        state $json = JSON::MaybeXS->new->allow_nonref;
         my $i = -1;
         return sub {
             state $eof;
@@ -1239,8 +1239,8 @@ sub display_result {
                     print "\n" unless $type eq 'buf';
                 }
             } else {
-                require JSON;
-                state $json = JSON->new->allow_nonref;
+                require JSON::MaybeXS;
+                state $json = JSON::MaybeXS->new->allow_nonref;
                 while (defined(my $rec = $x->())) {
                     print $json->encode($rec), "\n";
                 }
@@ -1435,7 +1435,7 @@ Perinci::CmdLine::Base - Base class for Perinci::CmdLine{::Classic,::Lite}
 
 =head1 VERSION
 
-This document describes version 1.51 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2016-02-26.
+This document describes version 1.52 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2016-03-16.
 
 =head1 DESCRIPTION
 
@@ -2244,7 +2244,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Cm
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Perinci-CmdLine-Lite>.
+Source repository is at L<https://github.com/sharyanto/perl-Perinci-CmdLine-Lite>.
 
 =head1 BUGS
 
